@@ -39,7 +39,7 @@ class TestViews(UnicoreTestCase):
             }
         })
 
-        languages = "[('eng_UK', 'English'), ('swh_KE', 'Swahili (Kenya)')]"
+        languages = "[('eng_GB', 'English'), ('swa_KE', 'Swahili (Kenya)')]"
         settings = {
             'git.path': self.workspace.repo.working_dir,
             'git.content_repo_url': '',
@@ -49,7 +49,7 @@ class TestViews(UnicoreTestCase):
             'cache.long_term.expire': '1',
             'cache.default_term.expire': '1',
             'available_languages': languages,
-            'pyramid.default_locale_name': 'eng_UK',
+            'pyramid.default_locale_name': 'eng_GB',
         }
         self.config = testing.setUp(settings=settings)
         set_cache_regions_from_settings(settings)
@@ -91,8 +91,8 @@ class TestViews(UnicoreTestCase):
 
     def test_get_available_languages(self):
         languages = self.views.get_available_languages
-        self.assertEqual(languages[0][0], 'eng_UK')
-        self.assertEqual(languages[1][0], 'swh_KE')
+        self.assertEqual(languages[0][0], 'eng_GB')
+        self.assertEqual(languages[1][0], 'swa_KE')
         self.assertEqual(languages[1][1], 'Swahili (Kenya)')
 
     def test_get_featured_category_pages(self):
@@ -110,31 +110,31 @@ class TestViews(UnicoreTestCase):
 
         self.assertEqual(
             set([page1.language, page2.language]),
-            set(['eng_UK', 'eng_UK']))
+            set(['eng_GB', 'eng_GB']))
 
         self.assertEqual(
             [], list(self.views.get_featured_category_pages(category2.uuid)))
 
     def test_get_featured_category_pages_swahili(self):
-        self.views = CmsViews(testing.DummyRequest({'_LOCALE_': 'swh_KE'}))
+        self.views = CmsViews(testing.DummyRequest({'_LOCALE_': 'swa_KE'}))
 
         [category_eng] = self.create_categories(
-            self.workspace, language='eng_UK', count=1)
+            self.workspace, language='eng_GB', count=1)
         self.create_pages(
-            self.workspace, count=10, language='eng_UK',
+            self.workspace, count=10, language='eng_GB',
             primary_category=category_eng.uuid)
         self.create_pages(
-            self.workspace, count=2, language='eng_UK',
+            self.workspace, count=2, language='eng_GB',
             featured_in_category=True,
             primary_category=category_eng.uuid)
 
         [category_swh] = self.create_categories(
-            self.workspace, language='swh_KE', count=1)
+            self.workspace, language='swa_KE', count=1)
         self.create_pages(
-            self.workspace, count=10, language='swh_KE',
+            self.workspace, count=10, language='swa_KE',
             primary_category=category_swh.uuid)
         pages_swh_featured = self.create_pages(
-            self.workspace, count=2, language='swh_KE',
+            self.workspace, count=2, language='swa_KE',
             featured_in_category=True,
             primary_category=category_swh.uuid)
 
@@ -152,15 +152,15 @@ class TestViews(UnicoreTestCase):
                      category_swh.uuid)]))
 
     def test_get_page_by_slug(self):
-        self.create_pages(self.workspace, count=5, language='eng_UK')
-        self.create_pages(self.workspace, count=5, language='swh_KE')
+        self.create_pages(self.workspace, count=5, language='eng_GB')
+        self.create_pages(self.workspace, count=5, language='swa_KE')
 
-        p = self.views.get_page(None, 'test-page-1', 'eng_UK')
+        p = self.views.get_page(None, 'test-page-1', 'eng_GB')
         self.assertEqual(p.title, 'Test Page 1')
-        self.assertEqual(p.language, 'eng_UK')
+        self.assertEqual(p.language, 'eng_GB')
 
-        p = self.views.get_page(None, 'test-page-1', 'swh_KE')
-        self.assertEqual(p.language, 'swh_KE')
+        p = self.views.get_page(None, 'test-page-1', 'swa_KE')
+        self.assertEqual(p.language, 'swa_KE')
         self.assertEqual(self.views.get_page(None, 'invalid-slug'), None)
 
     def test_content_linked_pages(self):
@@ -230,9 +230,9 @@ class TestViews(UnicoreTestCase):
 
     def test_get_categories(self):
         category1, category2 = self.create_categories(
-            self.workspace, language='eng_UK')
+            self.workspace, language='eng_GB')
         category3, category4 = self.create_categories(
-            self.workspace, language='swh_KE')
+            self.workspace, language='swa_KE')
 
         cat1, cat2 = self.views.get_categories()
         self.assertEqual(
@@ -242,21 +242,21 @@ class TestViews(UnicoreTestCase):
         )
 
         # Change language
-        self.views = CmsViews(testing.DummyRequest({'_LOCALE_': 'swh_KE'}))
+        self.views = CmsViews(testing.DummyRequest({'_LOCALE_': 'swa_KE'}))
         cat1, cat2 = self.views.get_categories()
         self.assertEqual(
             set([cat1.language, cat2.language]),
-            set(['swh_KE', 'swh_KE']))
+            set(['swa_KE', 'swa_KE']))
 
     def test_categories_ordering(self):
         category1 = Category(
-            {'title': 'title 1', 'language': 'eng_UK', 'position': 3})
+            {'title': 'title 1', 'language': 'eng_GB', 'position': 3})
         category2 = Category(
-            {'title': 'title 2', 'language': 'eng_UK', 'position': 0})
+            {'title': 'title 2', 'language': 'eng_GB', 'position': 0})
         category3 = Category(
-            {'title': 'title 3', 'language': 'eng_UK', 'position': 1})
+            {'title': 'title 3', 'language': 'eng_GB', 'position': 1})
         category4 = Category(
-            {'title': 'title 4', 'language': 'eng_UK', 'position': 2})
+            {'title': 'title 4', 'language': 'eng_GB', 'position': 2})
         self.workspace.save(category1, 'Update position')
         self.workspace.save(category2, 'Update position')
         self.workspace.save(category3, 'Update position')
@@ -272,12 +272,12 @@ class TestViews(UnicoreTestCase):
 
     def test_get_category(self):
         [category] = self.create_categories(
-            self.workspace, count=1, language='swh_KE')
+            self.workspace, count=1, language='swa_KE')
         [page] = self.create_pages(
-            self.workspace, count=1, language='swh_KE',
+            self.workspace, count=1, language='swa_KE',
             primary_category=category.uuid)
 
-        request = testing.DummyRequest({'_LOCALE_': 'swh_KE'})
+        request = testing.DummyRequest({'_LOCALE_': 'swa_KE'})
         request.matchdict['category'] = category.uuid
         views = CmsViews(request)
         response = views.category()
@@ -288,16 +288,16 @@ class TestViews(UnicoreTestCase):
     def test_pages_ordering(self):
         [category] = self.create_categories(self.workspace, count=1)
         page1 = Page({
-            'title': 'title 1', 'language': 'eng_UK', 'position': 3,
+            'title': 'title 1', 'language': 'eng_GB', 'position': 3,
             'primary_category': category.uuid})
         page2 = Page({
-            'title': 'title 2', 'language': 'eng_UK', 'position': 0,
+            'title': 'title 2', 'language': 'eng_GB', 'position': 0,
             'primary_category': category.uuid})
         page3 = Page({
-            'title': 'title 3', 'language': 'eng_UK', 'position': 1,
+            'title': 'title 3', 'language': 'eng_GB', 'position': 1,
             'primary_category': category.uuid})
         page4 = Page({
-            'title': 'title 4', 'language': 'eng_UK', 'position': 2,
+            'title': 'title 4', 'language': 'eng_GB', 'position': 2,
             'primary_category': category.uuid})
         self.workspace.save(page1, 'Update position')
         self.workspace.save(page2, 'Update position')
@@ -319,16 +319,16 @@ class TestViews(UnicoreTestCase):
     def test_get_top_nav(self):
         category1, category2 = self.create_categories(self.workspace)
         category3, category4 = self.create_categories(
-            self.workspace, language='swh_KE', featured_in_navbar=True)
+            self.workspace, language='swa_KE', featured_in_navbar=True)
 
         self.assertEqual([], list(self.views.get_top_nav))
 
         # Change language
-        self.views = CmsViews(testing.DummyRequest({'_LOCALE_': 'swh_KE'}))
+        self.views = CmsViews(testing.DummyRequest({'_LOCALE_': 'swa_KE'}))
         cat1, cat2 = self.views.get_top_nav
         self.assertEqual(
             set([cat1.language, cat2.language]),
-            set(['swh_KE', 'swh_KE']))
+            set(['swa_KE', 'swa_KE']))
 
     def test_format_date_helper(self):
         views = CmsViews(testing.DummyRequest({}))
@@ -343,3 +343,29 @@ class TestViews(UnicoreTestCase):
         self.assertEqual(
             views.format_date('some invalid date'),
             'some invalid date')
+
+    def test_get_flatpage_using_old_swahili_code(self):
+        [category] = self.create_categories(self.workspace, count=1)
+        [page] = self.create_pages(
+            self.workspace, count=1, content='Sample page in swahili',
+            description='_emphasised_', language='swa_KE')
+
+        request = testing.DummyRequest({'_LOCALE_': 'swh_KE'})
+        request.matchdict['slug'] = page.slug
+        self.views = CmsViews(request)
+        response = self.views.flatpage()
+        self.assertEqual(
+            response['content'], '<p>Sample page in swahili</p>')
+
+    def test_get_flatpage_using_old_english_code(self):
+        [category] = self.create_categories(self.workspace, count=1)
+        [page] = self.create_pages(
+            self.workspace, count=1, content='Sample page in english',
+            description='_emphasised_', language='eng_GB')
+
+        request = testing.DummyRequest({'_LOCALE_': 'eng_UK'})
+        request.matchdict['slug'] = page.slug
+        self.views = CmsViews(request)
+        response = self.views.flatpage()
+        self.assertEqual(
+            response['content'], '<p>Sample page in english</p>')
